==> evatestdb-0.0.3-py3-none-any.whl: eva/eva_server.py <==
# coding=utf-8
# Copyright 2018-2020 EVA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import asyncio
import argparse

from eva.server.server import start_server
from eva.udfs.udf_bootstrap_queries import init_builtin_udfs
from eva.configuration.configuration_manager import ConfigurationManager
from eva.utils.logging_manager import LoggingManager
from eva.utils.logging_manager import LoggingLevel


def eva():
    """
        Start the eva system
    """

    # Get the hostname and port information from the configuration file
    config = ConfigurationManager()
    hostname = config.get_value('server', 'host')
    port = config.get_value('server', 'port')
    socket_timeout = config.get_value('server', 'socket_timeout')
    loop = asyncio.new_event_loop()
    stop_server_future = loop.create_future()

    # Launch server
    try:
        asyncio.run(start_server(host=hostname,
                                 port=port,
                                 loop=loop,
                                 socket_timeout=socket_timeout,
                                 stop_server_future=stop_server_future)
                    )

    except Exception as e:
        LoggingManager().log(e, LoggingLevel.CRITICAL)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--db', help='foo help')
    args = parser.parse_args()

    db_uri = 'sqlite:///eva_catalog.db'
    if args.db:
        db_uri = 'mysql+pymysql://{}/eva_catalog'.format(args.db)

    mode = ConfigurationManager().get_value('core', 'mode')
    ConfigurationManager().update_value('core',
                                        'sqlalchemy_database_uri', db_uri)
    init_builtin_udfs(mode=mode)
    eva()


if __name__ == '__main__':
    # execute only if run as the entry point into the program
    main()

==> evatestdb-0.0.8-py3-none-any.whl: eva/eva_server.py <==
# coding=utf-8
# Copyright 2018-2020 EVA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import asyncio
import argparse
import sys
import os

from eva.server.server import start_server
from eva.udfs.udf_bootstrap_queries import init_builtin_udfs
from eva.configuration.configuration_manager import ConfigurationManager
from eva.utils.logging_manager import LoggingManager
from eva.utils.logging_manager import LoggingLevel


def eva():
    """
        Start the eva system
    """

    # Get the hostname and port information from the configuration file
    config = ConfigurationManager()
    hostname = config.get_value('server', 'host')
    port = config.get_value('server', 'port')
    socket_timeout = config.get_value('server', 'socket_timeout')
    loop = asyncio.new_event_loop()
    stop_server_future = loop.create_future()

    # Launch server
    try:
        asyncio.run(start_server(host=hostname,
                                 port=port,
                                 loop=loop,
                                 socket_timeout=socket_timeout,
                                 stop_server_future=stop_server_future)
                    )

    except Exception as e:
        LoggingManager().log(e, LoggingLevel.CRITICAL)


def parse_args(args):
    parser = argparse.ArgumentParser()
    parser.add_argument('--db', help='foo help')
    return parser.parse_args(args)


def main():
    args = parse_args(sys.argv[1:])
    db_uri = 'sqlite://{}/eva_catalog.db'.format(os.getcwd())
    if args.db:
        db_uri = 'mysql+pymysql://{}/eva_catalog'.format(args.db)

    mode = ConfigurationManager().get_value('core', 'mode')
    ConfigurationManager().update_value('core',
                                        'sqlalchemy_database_uri', db_uri)
    init_builtin_udfs(mode=mode)
    eva()


if __name__ == '__main__':
    # execute only if run as the entry point into the program
    main()
